@@ -1,10 +1,10 @@
 use crate::utils::{dag, info, Error, Result, INTERNAL_ERR};
 use cargo_metadata::Metadata;
-use clap::{AppSettings, Clap};
+use clap::{AppSettings, Parser};
 use std::process::Command;
 
 /// Execute an arbitrary command in each crate
-#[derive(Debug, Clap)]
+#[derive(Debug, Parser)]
 #[clap(setting = AppSettings::TrailingVarArg)]
 pub struct Exec {
     /// Continue executing command despite non-zero exit in a given crate
